@@ -25,7 +25,9 @@ train_autoencoder <- function(data,
       feature_cols = feature_cols,
       epochs = epochs,
       batch_size = batch_size,
-      lr = lr
+      lr = lr,
+      model = NULL,
+      dataset = NULL
     ),
     class = "autoencoder"
   )
