@@ -8,5 +8,5 @@
 train_biomor <- function(data, feature_cols, epochs = 100, batch_size = 50, lr = 1e-3) {
   ae_obj <- train_autoencoder(data, feature_cols, epochs, batch_size, lr)
   emb <- get_embeddings(ae_obj, data, feature_cols)
-  list(model = ae_obj$model, dataset = ae_obj$dataset, embeddings = emb)
-}
\ No newline at end of file
+  list(model = ae_obj$model, dataset = ae_obj$data, embeddings = emb)
+}
