@@ -3,6 +3,8 @@
 # ============================
 
 test_that("RF model trains and predicts", {
+  skip_if_not_installed("randomForest")
+  
   # Simulated binary dataset
   set.seed(123)
   df <- data.frame(
@@ -17,11 +19,14 @@ test_that("RF model trains and predicts", {
   preds <- predict(fit, df)
   
   expect_s3_class(fit, "train")
-  expect_true(all(levels(preds) == c("Active", "Inactive")))
+  expect_true(all(levels(preds) %in% c("Active", "Inactive")))
   expect_length(preds, nrow(df))
 })
 
 test_that("XGB model trains and predicts", {
+  skip_on_cran()
+  skip_if_not_installed("xgboost")
+  
   # Simulated binary dataset
   set.seed(456)
   df <- data.frame(
@@ -36,6 +41,6 @@ test_that("XGB model trains and predicts", {
   preds <- predict(fit, df)
   
   expect_s3_class(fit, "train")
-  expect_true(all(levels(preds) == c("Active", "Inactive")))
+  expect_true(all(levels(preds) %in% c("Active", "Inactive")))
   expect_length(preds, nrow(df))
-})
\ No newline at end of file
+})
